@@ -37,10 +37,6 @@ def s_cond(scanner, token):
     return ('cond', token)
 
 
-def s_comment(scanner, token):
-    return
-
-
 def s_whitespace(scanner, token):
     return
 
@@ -55,9 +51,9 @@ scanner = re.Scanner([
     (r'\b(add|addi|and|andi|call|call|jmp|ld|ldi|ret|' +
      r'ldg|mul|muli|or|ori|setg|sll|slli|sra|srai|srl|' +
      r'srli|st|sti|stg|sub|subi|xor|xori|cmp|mv|neg|nop|not)\b', s_operator),
-    (r'/\*.*\*/', s_comment),
-    ('(equal|not equal|greater than|less than|greater than or equal|' +
-     r'overflow|not overflow|less than or equal|always|never|eq|neq|' +
-     'gt|lt|gte|lte|n|v|nv)[ \t\v]*:', s_condition),
+    ('(equal|not equal|greater than|greater than or equal|less than|' +
+     r'less than or equal|zero|not zero|positive|positive or zero|' +
+     r'negative|negative or zero|overflow|not overflow|never|always)',
+     s_condition),
     ('[^ :0-9\n\t\v][^ :\n\t\v]*', s_label),
 ])
